OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "الفواصل المرجعية",
    "Details" : "التفاصيل",
    "Rename" : "إعادة التسمية",
    "Move" : "نقل",
    "Delete" : "حذف ",
    "Select all" : "تحديد الكل",
    "New" : "جديد",
    "New folder" : "مجلد جديد",
    "Cancel" : "إلغاء",
    "Recent" : "الحديثة",
    "Import" : "استيراد",
    "Export" : "تصدير",
    "Clear data" : "مسح البيانات",
    "Title" : "العنوان",
    "Link" : "الرابط",
    "Tags" : "الوسوم",
    "Notes" : "الملاحظات",
    "Owner" : "المالك",
    "Sharing" : "المشاركة",
    "Share link" : "مشاركة الرابط",
    "Copy link" : "انسخ الرابط",
    "Allow editing" : "السماح بالتعديلات",
    "Link copied" : "نُسِخ الرابط",
    "Privacy" : "الخصوصية",
    "Previews" : "المعاينات",
    "Add a bookmark" : "إضافة فاصلة مرجعية",
    "Folder" : "مجلد",
    "Save" : "حفظ"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
